# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.12] - 2026-03-27

## [0.1.11] - 2026-03-27

### Docs
- Update docs/README.md
- Update project/context.md

### Other
- Update PKG-INFO
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/duplication.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- Update project/index.html
- Update project/map.toon.yaml
- Update project/project.toon.yaml
- ... and 2 more files

## [0.1.10] - 2026-03-27

### Docs
- Update docs/README.md
- Update project/context.md

### Other
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/compact_flow.mmd
- Update project/duplication.toon.yaml
- Update project/evolution.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- Update project/index.html
- Update project/map.toon.yaml
- ... and 1 more files

## [0.1.9] - 2026-03-27

### Docs
- Update CHANGELOG.md
- Update README.md
- Update docs/README.md
- Update project/README.md
- Update project/context.md

### Other
- Update prefact.yaml
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/compact_flow.mmd
- Update project/compact_flow.png
- Update project/duplication.toon.yaml
- Update project/evolution.toon.yaml
- Update project/flow.mmd
- Update project/flow.png
- ... and 7 more files

## [0.1.8] - 2026-03-27

### Docs
- Update docs/README.md
- Update project/README.md
- Update project/context.md

### Other
- Update project.sh
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/duplication.toon.yaml
- Update project/evolution.toon.yaml
- Update project/flow.png
- Update project/index.html
- Update project/map.toon.yaml
- Update project/project.toon.yaml
- ... and 4 more files

## [0.1.7] - 2026-03-27

### Docs
- Update project/context.md

### Other
- Update project.sh
- Update project/analysis.toon.yaml
- Update project/calls.mmd
- Update project/calls.png
- Update project/compact_flow.mmd
- Update project/compact_flow.png
- Update project/flow.mmd
- Update project/map.toon.yaml

## [0.1.6] - 2026-03-27

### Other
- Update examples/run_examples.py
- Update planfile.yaml
- Update prefact.yaml

## [0.1.5] - 2026-03-27

### Docs
- Update examples/README.md
- Update vscode-extension/node_modules/@eslint-community/eslint-utils/README.md
- Update vscode-extension/node_modules/@eslint-community/regexpp/README.md
- Update vscode-extension/node_modules/@eslint/eslintrc/README.md
- Update vscode-extension/node_modules/@eslint/eslintrc/node_modules/brace-expansion/README.md
- Update vscode-extension/node_modules/@eslint/eslintrc/node_modules/minimatch/README.md
- Update vscode-extension/node_modules/@eslint/js/README.md
- Update vscode-extension/node_modules/@humanwhocodes/config-array/README.md
- Update vscode-extension/node_modules/@humanwhocodes/config-array/node_modules/brace-expansion/README.md
- Update vscode-extension/node_modules/@humanwhocodes/config-array/node_modules/minimatch/README.md
- ... and 297 more files

### Other
- Update examples/07-enterprise/prefact.yaml
- Update examples/08-llm-focused/prefact.yaml
- Update examples/09-high-performance/prefact.yaml
- Update examples/10-plugin-development/prefact.yaml
- Update examples/11-ci-cd/prefact.yaml
- Update examples/12-complete-example/prefact.yaml
- Update examples/requirements.txt
- Update src/prefact/VERSION
- Update vscode-extension/node_modules/.bin/acorn
- Update vscode-extension/node_modules/.bin/eslint
- ... and 965 more files

## [0.1.4] - 2026-03-27

### Docs
- Update README.md
- Update docs/MIGRATION_GUIDE.md
- Update examples/01-individual-rules/README.md
- Update examples/06-api-usage/README.md
- Update examples/README.md
- Update examples/sample-project/README.md

### Test
- Update tests/test_integrations.py

### Other
- Update examples/requirements.txt

## [0.1.3] - 2026-03-27

### Docs
- Update examples/01-individual-rules/duplicate-imports/README.md
- Update examples/01-individual-rules/missing-return-type/README.md
- Update examples/01-individual-rules/print-statements/README.md
- Update examples/01-individual-rules/relative-imports/README.md
- Update examples/01-individual-rules/sorted-imports/README.md
- Update examples/01-individual-rules/string-concat/README.md
- Update examples/01-individual-rules/wildcard-imports/README.md

### Other
- Update examples/03-output-formats/test-report.json
- Update examples/run_all.sh

## [0.1.2] - 2026-03-27

### Docs
- Update README.md
- Update examples/01-individual-rules/README.md
- Update examples/02-multiple-rules/README.md
- Update examples/03-output-formats/README.md
- Update examples/04-custom-rules/README.md
- Update examples/05-ci-cd/README.md
- Update examples/06-api-usage/README.md
- Update examples/README.md
- Update examples/sample-project/README.md

### Other
- Update examples/01-individual-rules/duplicate-imports/after.py
- Update examples/01-individual-rules/duplicate-imports/before.py
- Update examples/01-individual-rules/duplicate-imports/prefact.yaml
- Update examples/01-individual-rules/missing-return-type/after.py
- Update examples/01-individual-rules/missing-return-type/before.py
- Update examples/01-individual-rules/missing-return-type/prefact.yaml
- Update examples/01-individual-rules/print-statements/after.py
- Update examples/01-individual-rules/print-statements/before.py
- Update examples/01-individual-rules/print-statements/prefact.yaml
- Update examples/01-individual-rules/relative-imports/after.py
- ... and 39 more files

## [0.1.1] - 2026-03-27

### Docs
- Update README.md

### Test
- Update tests/test_config.py
- Update tests/test_engine.py
- Update tests/test_relative_imports.py
- Update tests/test_rules.py
- Update tests/test_unused_imports.py

### Other
- Update PKG-INFO
- Update VERSION
- Update prefact/__init__.py
- Update prefact/cli.py
- Update prefact/core.py
- Update prefact/utils.py

## [0.0.6] - 2026-03-27

### Docs
- Update README.md

### Test
- Update tests/test_prefactoring.py

### Other
- Update MANIFEST.in
- Update prefact/__init__.py
- Update prefact/cli.py
- Update prefact/core.py
- Update prefact/utils.py

## [0.0.5] - 2026-03-27

### Other
- Update .idea/inspectionProfiles/Project_Default.xml
- Update .idea/inspectionProfiles/profiles_settings.xml
- Update .idea/misc.xml
- Update .idea/modules.xml
- Update .idea/prefactoring.iml
- Update .idea/vcs.xml

## [0.0.4] - 2026-03-27

## [0.0.3] - 2026-03-27

### Other
- Update MANIFEST.in

## [0.0.2] - 2026-03-27

### Test
- Update tests/test_prefactoring.py

### Other
- Update prefactoring/__init__.py
- Update prefactoring/cli.py
- Update prefactoring/core.py
- Update prefactoring/utils.py

## [0.0.1] - 2026-03-27

### Other
- Update .idea/.gitignore

